==> knative-model-4.7.1-sources.jar: io/fabric8/knative/eventing/v1alpha1/TriggerSpecFluent.java <==
package io.fabric8.knative.eventing.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface TriggerSpecFluent<A extends TriggerSpecFluent<A>> extends Fluent<A>{


    public String getBroker();
    public A withBroker(String broker);
    public Boolean hasBroker();
    public A withNewBroker(String arg1);
    public A withNewBroker(StringBuilder arg1);
    public A withNewBroker(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildFilter instead.
 * @return The buildable object.
 */
@Deprecated public TriggerFilter getFilter();
    public TriggerFilter buildFilter();
    public A withFilter(TriggerFilter filter);
    public Boolean hasFilter();
    public TriggerSpecFluent.FilterNested<A> withNewFilter();
    public TriggerSpecFluent.FilterNested<A> withNewFilterLike(TriggerFilter item);
    public TriggerSpecFluent.FilterNested<A> editFilter();
    public TriggerSpecFluent.FilterNested<A> editOrNewFilter();
    public TriggerSpecFluent.FilterNested<A> editOrNewFilterLike(TriggerFilter item);
    
/**
 * This method has been deprecated, please use method buildSubscriber instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.knative.eventing.v1alpha1.SubscriberSpec getSubscriber();
    public io.fabric8.knative.eventing.v1alpha1.SubscriberSpec buildSubscriber();
    public A withSubscriber(io.fabric8.knative.eventing.v1alpha1.SubscriberSpec subscriber);
    public Boolean hasSubscriber();
    public TriggerSpecFluent.SubscriberNested<A> withNewSubscriber();
    public TriggerSpecFluent.SubscriberNested<A> withNewSubscriberLike(io.fabric8.knative.eventing.v1alpha1.SubscriberSpec item);
    public TriggerSpecFluent.SubscriberNested<A> editSubscriber();
    public TriggerSpecFluent.SubscriberNested<A> editOrNewSubscriber();
    public TriggerSpecFluent.SubscriberNested<A> editOrNewSubscriberLike(io.fabric8.knative.eventing.v1alpha1.SubscriberSpec item);

    public interface FilterNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TriggerFilterFluent<TriggerSpecFluent.FilterNested<N>>{

        
    public N and();    public N endFilter();
}
    public interface SubscriberNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.eventing.v1alpha1.SubscriberSpecFluent<TriggerSpecFluent.SubscriberNested<N>>{

        
    public N and();    public N endSubscriber();
}


}

==> knative-model-4.9.0-sources.jar: io/fabric8/knative/eventing/v1alpha1/TriggerSpecFluent.java <==
package io.fabric8.knative.eventing.v1alpha1;

import io.fabric8.knative.duck.v1.Destination;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.duck.v1.DestinationFluent;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.knative.duck.v1.DestinationBuilder;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface TriggerSpecFluent<A extends TriggerSpecFluent<A>> extends Fluent<A>{


    public String getBroker();
    public A withBroker(String broker);
    public Boolean hasBroker();
    public A withNewBroker(String arg1);
    public A withNewBroker(StringBuilder arg1);
    public A withNewBroker(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildFilter instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public TriggerFilter getFilter();
    public TriggerFilter buildFilter();
    public A withFilter(TriggerFilter filter);
    public Boolean hasFilter();
    public TriggerSpecFluent.FilterNested<A> withNewFilter();
    public TriggerSpecFluent.FilterNested<A> withNewFilterLike(TriggerFilter item);
    public TriggerSpecFluent.FilterNested<A> editFilter();
    public TriggerSpecFluent.FilterNested<A> editOrNewFilter();
    public TriggerSpecFluent.FilterNested<A> editOrNewFilterLike(TriggerFilter item);
    
/**
 * This method has been deprecated, please use method buildSubscriber instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public Destination getSubscriber();
    public Destination buildSubscriber();
    public A withSubscriber(Destination subscriber);
    public Boolean hasSubscriber();
    public TriggerSpecFluent.SubscriberNested<A> withNewSubscriber();
    public TriggerSpecFluent.SubscriberNested<A> withNewSubscriberLike(Destination item);
    public TriggerSpecFluent.SubscriberNested<A> editSubscriber();
    public TriggerSpecFluent.SubscriberNested<A> editOrNewSubscriber();
    public TriggerSpecFluent.SubscriberNested<A> editOrNewSubscriberLike(Destination item);

    public interface FilterNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TriggerFilterFluent<TriggerSpecFluent.FilterNested<N>>{

        
    public N and();    public N endFilter();
}
    public interface SubscriberNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DestinationFluent<TriggerSpecFluent.SubscriberNested<N>>{

        
    public N and();    public N endSubscriber();
}


}
